import os
import shutil
from glob import glob
from pathlib import Path

import fire

from ensemble_eeg import ensemble_edf


def anonymize_eeg_ensemble(input_dir, output_dir):
    """Anonymize the edf files in input_dir using the ensemble_edf
    anonymize_edf_header function, then move the anonymized edf files in
    output_dir.

    Parameters
    ----------
    input_dir: str
        Path to the input directory where the edf to anonymize are
        stored
    output_dir: str
        Path where the anonymized edf are generated.
    """
    # check input and output are different
    assert input_dir != output_dir, (
        "Input and output directories are the same. "
        "Please change the output directory to avoid overwriting "
        "the input data."
    )

    # check input and output are directories, not files
    assert os.path.isdir(input_dir), (
        f"First argument supposed to be a directory. Received {input_dir}"
    )
    assert os.path.isdir(output_dir), (
        f"Second argument supposed to be a directory. Received {output_dir}"
    )

    # get all the edf files in input_dir
    input_eeg = glob(os.path.join(input_dir, "*.edf"))

    print(f"Number of eeg to anonymize: {len(input_eeg)}")

    # create the output directory if needed
    if not os.path.exists(output_dir):
        os.makedirs(output_dir)

    for eeg_path in input_eeg:
        # anonymize the header using an ensemble_edf function
        ensemble_edf.anonymize_edf_header(eeg_path)
        # path where the anonymized edf is generated by ensemble_edf
        eeg_path = Path(eeg_path)
        eeg_anon_path = os.path.join(
            eeg_path.parent,
            f"{eeg_path.stem}_ANONYMIZED{eeg_path.suffix}",
        )
        # move the anonymized edf in the output directory
        # and replace ANONYMIZED by the chosen suffix
        eeg_output_path = eeg_anon_path.replace(input_dir, output_dir)
        eeg_output_path = eeg_output_path.replace("_ANONYMIZED", "")
        shutil.move(eeg_anon_path, eeg_output_path)


def _anonymize_eeg_ensemble_main():
    fire.Fire(anonymize_eeg_ensemble)


if __name__ == "__main__":
    _anonymize_eeg_ensemble_main()
